==> mydns_0.9.2.orig.tar.gz: mydns-0.9.2/src/util/util.h <==
/**************************************************************************************************
	$Header: /pub/cvsroot/mydns/src/util/util.h,v 1.6 2002/09/12 04:50:42 bboy Exp $

	Copyright (C) 2002  Don Moore <bboy@bboy.net>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at Your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************************************************************************/

#ifndef _MYDNS_UTIL_DIR_H
#define _MYDNS_UTIL_DIR_H

#include "mydnsutil.h"
#include "mydns.h"

/* I'm not done with tinydns-data support yet.  It won't work.  Defining this and compiling
	won't work. */
#undef  TINYDNS_IMPORT

extern CONF *Conf;												/* Configuration data */
extern MYSQL *mysql;												/* MySQL connection */


extern void load_config(void);
extern void db_connect(void);
extern u_int32_t sqlnum(const char *, ...) __printflike(1,2);
extern inline void meter(unsigned long, unsigned long);
extern time_t tai64time(char *);


#endif /* !_MYDNS_UTIL_DIR_H */

/* vi:set ts=3: */

==> mydns_0.11.0.orig.tar.gz: mydns-0.11.0/src/util/util.h <==
/**************************************************************************************************
	$Header: /pub/cvsroot/mydns/src/util/util.h,v 1.11 2003/07/17 22:49:25 bboy Exp $

	Copyright (C) 2002-2003  Don Moore <bboy@bboy.net>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at Your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**************************************************************************************************/

#ifndef _MYDNS_UTIL_DIR_H
#define _MYDNS_UTIL_DIR_H

#include "mydnsutil.h"
#include "mydns.h"

/* I'm not done with tinydns-data support yet.  It won't work.
	Defining this and recompiling will NOT let you import tinydns-data files! */
#define TINYDNS_IMPORT

extern CONF *Conf;												/* Configuration data */

extern void load_config(void);
extern void db_connect(void);
extern uint32_t sqlnum(const char *, ...) __printflike(1,2);
extern inline void meter(unsigned long, unsigned long);


#endif /* !_MYDNS_UTIL_DIR_H */

/* vi:set ts=3: */
